@@ -1,7 +1,7 @@
 /************************************************************************
 * config.c
 * nodau console note taker
-* Copyright (C) Lisa Milne 2012 <lisa@ltmnet.com>
+* Copyright (C) Lisa Milne 2012-2013 <lisa@ltmnet.com>
 *
 * lib.c is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
@@ -78,6 +78,8 @@ static FILE *config_file(char* mode)
 
 	/* use XDG config directory */
 	if (!xch || !xch[0]) {
+		if (!f || !f[0])
+			return NULL;
 		if (asprintf(&fl,"%s/.config/nodau",f) < 0)
 			return NULL;
 	}else{
@@ -87,11 +89,12 @@ static FILE *config_file(char* mode)
 
 	dir_create(fl);
 
-	strcat(fl,"/nodau.conf");
-
-	r = fopen(fl,mode);
-
+	f = alloca(strlen(fl)+12);
+	strcpy(f,fl);
 	free(fl);
+	strcat(f,"/nodau.conf");
+
+	r = fopen(f,mode);
 
 	return r;
 }
